@@ -4,12 +4,13 @@ use std::collections::HashMap;
 #[cfg(feature = "rayon")]
 use rayon::prelude::*;
 
-use crate::{CIndexResult, CIndexError};
+use crate::{CIndexResult, CIndexError, consts};
 use crate::models::{CsvType, CsvTable, Query};
 
 /// Entry struct for indexing csv tables
 pub struct Indexer {
     print_header: bool,
+    always_unix_newline: bool,
     tables: HashMap<String, CsvTable>,
 }
 
@@ -18,6 +19,7 @@ impl Indexer {
     pub fn new() -> Self {
         Self {
             print_header: true,
+            always_unix_newline: false,
             tables: HashMap::new(),
         }
     }
@@ -27,6 +29,19 @@ impl Indexer {
         self.print_header = tv;
     }
 
+    /// Always use unix newline for formatting
+    pub fn always_use_unix_newline(&mut self, tv:bool) {
+        self.always_unix_newline = tv;
+    }
+
+    fn get_newline(&self) -> &str {
+        if self.always_unix_newline {
+            "\n"
+        } else {
+            consts::LINE_ENDING
+        }
+    }
+
     /// Add table without header
     pub fn add_table_fast(&mut self, table_name: &str, input: impl Read) -> CIndexResult<()>{
         self.add_table(table_name, vec![], input)
@@ -83,7 +98,7 @@ impl Indexer {
 
         let filtered_rows = table.query(&query)?;
         let mut rows_iter = filtered_rows.iter();
-        let columns: Option<Vec<usize>> = if let Some(cols) = query.column_names {
+        let columns: Option<Vec<usize>> = if let Some(ref cols) = query.column_names {
             if cols.len() > 0 && cols[0] == "*" { None }
             else {
                 #[cfg(feature = "rayon")]
@@ -100,41 +115,28 @@ impl Indexer {
 
         // Print headers
         if self.print_header {
-            if let Some(cols) = &columns {
-                // Print headers
-                self.write(&(self.header_splited(&table, &cols) + "\n"), &mut out_option)?;
-            } else { // print normal headers
-                self.write(&(table.headers.iter().map(|s| s.as_str()).collect::<Vec<&str>>().join(",") + "\n"), &mut out_option)?;
+            let columns = query.column_names.unwrap_or(vec!["*".to_owned()]);
+            if columns[0] == "*" {
+                let headers = table.headers.iter().map(|s| s.as_str()).collect::<Vec<&str>>();
+                self.write(&(headers.join(",") + self.get_newline()), &mut out_option)?;
+            } else {
+                let map = query.column_map.unwrap_or(vec![]);
+                let columns = map.iter().chain(columns[map.len()..].iter()).map(|s| s.as_str()).collect::<Vec<&str>>().join(",");
+                self.write(&(columns + self.get_newline()), &mut out_option)?;
             }
         }
 
         while let Some(&row) = rows_iter.next() {
             let row_string = if let Some(cols) = &columns {
-                row.column_splited(cols) + "\n"
+                row.column_splited(cols) + self.get_newline()
             } else {
-                row.to_string() + "\n"
+                row.to_string() + self.get_newline()
             };
             self.write(&row_string, &mut out_option)?;
         }
         Ok(())
     }
 
-    fn header_splited(&self, table : &CsvTable, columns: &Vec<usize>) -> String {
-        let mut col_iter = columns.iter();
-        let mut formatted = String::new();
-
-        // First item
-        if let Some(col) = col_iter.next() {
-            formatted.push_str(&table.headers[*col].to_string());
-        }
-
-        while let Some(col) = col_iter.next() {
-            formatted.push(',');
-            formatted.push_str(&table.headers[*col].to_string());
-        }
-        formatted
-    }
-
     fn write(&self, content: &str, out_option: &mut OutOption) -> CIndexResult<()> {
         match out_option {
             OutOption::Term => print!("{}", content),
